<?php
/**
* @package   BaForms
* @author    Balbooa http://www.balbooa.com/
* @copyright Copyright @ Balbooa
* @license   http://www.gnu.org/licenses/gpl.html GNU/GPL
*/

defined('_JEXEC') or die;

// import Joomla controllerform library
jimport('joomla.application.component.controllerform');
jimport('joomla.filesystem.folder');
jimport('joomla.filesystem.file');

class BagridControllerBagrid extends JControllerForm
{
    public function getModel($name = '', $prefix = '', $config = array('ignore_request' => true))
	{
		return parent::getModel($name, $prefix, array('ignore_request' => false));
	}

    public function parseHttpRequest()
    {
        $input = file_get_contents('php://input');
        $data = array();
        preg_match('/boundary=(.*)$/', $_SERVER['CONTENT_TYPE'], $matches);
        if (!count($matches)) {
            parse_str(urldecode($input), $data);
            return $data;
        }
        $boundary = $matches[1];
        $blocks = preg_split("/-+$boundary/", $input);
        array_pop($a_blocks);
        foreach ($blocks as $id => $block) {
            if (empty($block))
                continue;
            if (strpos($block, 'application/octet-stream') !== FALSE) {
                preg_match("/name=\"([^\"]*)\".*stream[\n|\r]+([^\n\r].*)?$/s", $block, $matches);
                $data['files'][$matches[1]] = $matches[2];
            } else {
                preg_match('/name=\"([^\"]*)\"[\n|\r]+([^\n\r].*)?\r$/s', $block, $matches);
                $data[$matches[1]] = $matches[2];
            }
        }
        return $data;
    }

    public function checkPostData()
    {
        if (empty($_POST) && function_exists('file_get_contents') && function_exists('parse_str')) {
            $_POST = $this->parseHttpRequest();
        }
    }
    
    public function save($key = NULL, $urlVar = NULL)
    {
        $this->checkPostData();
        $id = $_POST['grid_id'];
        $redirect = JUri::base(). 'index.php?option=com_bagrid&view=bagrid&id=' .$id.'&save=';
        $model = $this->getModel();
        if ($model->save()) {
            $this->setRedirect($redirect. 'success');
        } else {
            $this->setRedirect($redirect.'error');
        }
    }

    public function getpageNavigation()
    {
        $this->checkPostData();
        $categories = $_POST['categories'];
        $id = $_POST['id'];
        $items = bagridHelper::getPageNavigation($id, $categories);
        $items = json_encode($items);
        echo new JResponseJson(true, $items);
        exit;
    }

    public function getCategoryList()
    {
        $this->checkPostData();
        $categories = $_POST['categories'];
        $items = bagridHelper::getCategoryList($categories);
        $items = json_encode($items);
        echo new JResponseJson(true, $items);
        exit;
    }

    public function getTagCloud()
    {
        $this->checkPostData();
        $order = $_POST['order'];
        $limit = $_POST['limit'];
        $items = bagridHelper::getTagCloud($order, $limit);
        $items = json_encode($items);
        echo new JResponseJson(true, $items);
        exit;
    }

    public function getBlogPosts()
    {
        $this->checkPostData();
        $category = $_POST['category'];
        $limit = $_POST['limit'];
        $start = $_POST['start'];
        $posts = bagridHelper::getBlogPosts($category, $start, $limit);
        foreach ($posts as $post) {
            if (!empty($post->page_category)) {
                $post->category = bagridHelper::getCategoryTitle($post->page_category);
            } else {
                $post->category = '';
            }
        }
        $posts = json_encode($posts);
        echo new JResponseJson(true, $posts);
        exit;
    }

    public function getPageTags()
    {
        $this->checkPostData();
        $id = $_POST['page_id'];
        $tags = bagridHelper::getPageTags($id);
        $tags = json_encode($tags);
        echo new JResponseJson(true, $tags);
        exit;
    }
    
    public function getLibraryList()
    {
        $this->checkPostData();
        $type = $_POST['ba_type'];
        $db = JFactory::getDbo();
        $query = $db->getQuery(true);
        $query->select('*')
            ->from('`#__bagrid_library`')
            ->where('`type` = '.$db->Quote($type))
            ->order($db->escape('`title` asc'));
        $db->setQuery($query);
        $items = $db->loadObjectList();
        foreach ($items as $item) {
            $item->item = bagridHelper::restoreImages($item->item);
        }
        $items = json_encode($items);
        echo new JResponseJson($items);
        exit;
    }
    
    public function deleteLibraryItem()
    {
        $this->checkPostData();
        $lid = $_POST['item_id'];
        $lid = explode(',', $lid);
        $db = JFactory::getDbo();
        foreach ($lid as $id) {
            $query = $db->getQuery(true);
            $conditions = array($db->quoteName('id') . ' = ' .$id);
            $query->delete($db->quoteName('#__bagrid_library'))
                ->where($conditions);
            $db->setQuery($query)
                ->execute();
        }
        echo new JResponseJson(true);
        exit;
    }
    
    public function globalLibrary()
    {
        $this->checkPostData();
        $content = stripcslashes($_POST['ba_data']);
        $item = $_POST['ba_item'];
        if (strpos($item, 'section')) {
            $regex = '/\[section=+(.*?)\]/i';
        } else {
            $regex = '/\[plugin=+(.*?)\]/i';
        }
        preg_match_all($regex, $content, $matches, PREG_SET_ORDER);
        if ($matches) {
            foreach ($matches as $index => $match) {
                $db = JFactory::getDbo();
                $query = $db->getQuery(true);
                $fields = array('`item` = ' .$db->quote($content));
                $conditions = array('`id` = ' .$db->quote($match[1]));
                $query->update($db->quoteName('#__bagrid_library'))
                    ->set($fields)
                    ->where($conditions);
                $db->setQuery($query)
                    ->execute();
                echo new JResponseJson($match[1]);
                exit;
            }
        }
    }
    
    public function addToLibrary()
    {
        $this->checkPostData();
        $title = $_POST['ba_title'];
        $item = stripcslashes($_POST['ba_item']);
        $type = $_POST['ba_type'];
        $global = $_POST['ba_global'];
        $db = JFactory::getDbo();
        $query = $db->getQuery(true);
        $columns = array('title', 'item', 'type', 'global_item');
        $values = array($db->quote($title), $db->quote($item),
                        $db->quote($type), $db->quote($global));
        $query->insert($db->quoteName('#__bagrid_library'))
            ->columns($db->quoteName($columns))
            ->values(implode(',', $values));
        $db->setQuery($query)
            ->execute();
        if ($global == 'true') {
            $resp = $db->insertid();
            $item = str_replace('global-item=ID', $type.'='.$resp, $item);
            $query = $db->getQuery(true);
            $fields = array('`item` = ' .$db->quote($item));
            $conditions = array('`id` = ' .$db->quote($resp));
            $query->update($db->quoteName('#__bagrid_library'))
                ->set($fields)
                ->where($conditions);
            $db->setQuery($query)
                ->execute();
        } else {
            $resp = true;
        }
        echo new JResponseJson($resp);
        exit;
    }
    
    public function getContentsCurl($url)
    {
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_HEADER, 0);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($ch, CURLOPT_URL, $url);
        $data = curl_exec($ch);
        curl_close($ch);
        
        return $data;
    }
    
    public function downloadPlugin()
    {
        $this->checkPostData();
        $flag = true;
        $plugin = $_POST['plugin_data'];
        $this->checkPlugin($plugin);
        $db = JFactory::getDbo();
        $query = $db->getQuery(true);
        $query->select("manifest_cache");
        $query->from("#__extensions");
        $query->where("type=" .$db->quote('component'))
            ->where('element=' .$db->quote('com_bagrid'));
        $db->setQuery($query);
        $about = $db->loadResult();
        $about = json_decode($about);
        $version = $about->version;
        $version = str_replace('.', '', $version);
        $url = 'http://www.balbooa.com/updates/bagrid/com_bagrid_update.xml';
        $curl = $this->getContentsCurl($url);
        $xml = simplexml_load_string($curl);
        $newVersion = (string)$xml->version;
        $newVersion = str_replace('.', '', $newVersion);
        $exp = strlen($version);
        $pow = pow(10, $exp);
        $version = $version / $pow;
        $exp = strlen($newVersion);
        $pow = pow(10, $exp);
        $newVersion = $newVersion / $pow;
        if ($newVersion > $version) {
            $flag = false;
        } else {
            $flag = true;
        }
        if (!$flag) {
            $target = 'http://www.balbooa.com/updates/bagrid/pkg_Gridbox.zip';
            $config = JFactory::getConfig();
            $path = $config->get('tmp_path') . '/pkg_Gridbox.zip';
            $ch = curl_init();
            curl_setopt($ch, CURLOPT_URL, $target);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
            curl_setopt($ch, CURLOPT_SSLVERSION, 3);
            $data = curl_exec($ch);
            curl_close($ch);
            $file = fopen($path, "w+");
            fputs($file, $data);
            fclose($file);
            JArchive::extract($path, $config->get('tmp_path') . '/pkg_Gridbox');
            $installer = JInstaller::getInstance();
            $result = $installer->update($config->get('tmp_path') . '/pkg_Gridbox');
            JFile::delete($path);
            JFolder::delete( $config->get('tmp_path') . '/pkg_Gridbox' );
        }
        $plugin = explode(';', $plugin);
        $db = JFactory::getDbo();
        $query = $db->getQuery(true);
        $columns = array(
            'title', 
            'image', 
            'joomla_constant'
        );
        $values = array(
            $db->Quote($plugin[0]), 
            $db->Quote($plugin[1]), 
            $db->Quote($plugin[2])
        );
        $query->insert($db->quoteName('#__bagrid_plugins'))
            ->columns($db->quoteName($columns))
            ->values(implode(',', $values));
        $db->setQuery($query)
            ->execute();
        $plugin[2] = JText::_($plugin[2]);
        echo new JResponseJson(true, implode(';', $plugin));
        exit;
    }
    
    public function checkPlugin($plugin) {
        $plugin = explode(';', $plugin);
        $db = JFactory::getDbo();
        $query = $db->getQuery(true);
        $query->select('id')
            ->from('#__bagrid_plugins')
            ->where('`title` = ' .$db->Quote($plugin[0]));
        $db->setQuery($query);
        $id = $db->loadResult();
        if (!empty($id)) {
            echo new JResponseJson(true, 'already');
            exit;
        }
    }
}