/**
* @package   BaGrid
* @author    Balbooa http://www.balbooa.com/
* @copyright Copyright @ Balbooa
* @license   http://www.gnu.org/licenses/gpl.html GNU/GPL
*/

!function ($) {
    
    var ba_slider = function (element, options) {
        this.parent = $(element);
        this.dots = this.parent.find('.ba-slider-dots');
        this.options = options;
        this.flag = true;
        if (this.options.pause == 1) {
            this.parent.on('mouseenter', $.proxy(this.pause, this))
                       .on('mouseleave', $.proxy(this.cycle, this))
        }
        if (this.options.navigation == 1 && this.dots.find('> div').length > 1) {
            this.setNavigation();
        }
    }
    
    ba_slider.prototype = {
        cycle: function (event) {
            if (this.options.autoplay == 1) {
                this.flag = true;
                if (this.interval) {
                    clearInterval(this.interval);
                }
                this.interval = setInterval($.proxy(this.next, this), this.options.interval);
                return this;
            }
        },
        setNavigation: function(){
            this.parent.addClass('navigation-style');
            var active = this.getActiveIndex(),
                items = this.parent.find('.item'),
                ind = active - 1,
                div = document.createElement('div'),
                h3 = document.createElement('h3'),
                img;
            if (ind < 0 ) {
                ind = items.length - 1;
            }
            img = $(items[ind]).find('.ba-slide-img').attr('data-img-url');
            this.parent.find('.navigation-prev-content, .navigation-next-content').remove();
            if (img) {
                $(h3).css(this.options.style);
                $(h3).text($(items[ind]).find('.ba-slider-title').text());
                div.className = 'navigation-prev-content';
                div.style.backgroundImage = 'url('+img+')';
                div.appendChild(h3);
                this.parent.find('.slider-btn-prev').after(div);
            }
            ind = active * 1 + 1;
            if (ind == items.length) {
                ind = 0;
            }
            img = $(items[ind]).find('.ba-slide-img').attr('data-img-url');
            if (img) {
                div = document.createElement('div');
                h3 = document.createElement('h3')
                div.className = 'navigation-next-content';
                div.style.backgroundImage = 'url('+img+')';
                $(h3).css(this.options.style);
                $(h3).text($(items[ind]).find('.ba-slider-title').text());
                div.appendChild(h3);
                this.parent.find('.slider-btn-next').after(div);
            }
            var $this = this;
            $('.navigation-prev-content').on('click', function(){
                $this.parent.find('.slider-btn-prev').trigger('click');
            });
            $('.navigation-next-content').on('click', function(){
                $this.parent.find('.slider-btn-next').trigger('click');
            });
        },
        delete: function(){
            if (this.interval) {
                clearInterval(this.interval);
            }
            this.parent.removeClass(this.options.effect);
            this.interval = null;
            this.parent.find('[data-slide]').off('click.ba_slider');
            this.parent.find('[data-ba-slide-to]').off('click.ba_slider');
            this.parent.removeClass('navigation-style');
            this.parent.find('.navigation-prev-content, .navigation-next-content').remove();
            this.parent.off();
        },
        getActiveIndex: function () {
            this.active = this.parent.find('.item.active');
            this.items = this.active.parent().find('li');
            return this.items.index(this.active);
        },
        to: function (pos) {
            var activeIndex = this.getActiveIndex();
            if (activeIndex == pos) {
                return this.cycle();
            }
            if (this.interval) {
                clearInterval(this.interval);
            }
            return this.slide(pos > activeIndex ? 'next' : 'prev', $(this.items[pos]));
        },
        next: function () {
            if (this.interval) {
                clearInterval(this.interval);
            }
            return this.slide('next');
        },
        pause: function() {
            if (this.interval) {
                clearInterval(this.interval);
            }
            this.interval = null;
            this.flag = false;
        },
        prev: function () {
            if (this.interval) {
                clearInterval(this.interval);
            }
            return this.slide('prev');
        },
        slide: function (type, next) {
            var active = this.parent.find('.item.active'),
                $next = next || active[type](),
                fallback  = type == 'next' ? 'first' : 'last',
                event,
                parent = this.parent;
            if ($next.length) {
                $next = $next;
            } else {
                $next = parent.find('.item')[fallback]();
            }
            parent.find('.select-animation').removeClass('select-animation');
            event = $.Event('slide', {
                prevItem : active[0],
                currentItem : $next[0]
            });
            if ($next.hasClass('active')) {
                return;
            }
            parent.find('.ba-next').removeClass('ba-next');
            parent.find('.ba-prev').removeClass('ba-prev');
            parent.find('.ba-left').removeClass('ba-left');
            parent.find('.ba-right').removeClass('ba-right');
            if (fallback == 'first') {
                active.addClass('ba-next').addClass('burns-out');;
                $next.addClass('ba-right');
            } else {
                active.addClass('ba-prev').addClass('burns-out');
                $next.addClass('ba-left');
            }
            setTimeout(function(){
                parent.find('.burns-out').removeClass('burns-out')
            }, 600);
            active.removeClass('active');
            $next.addClass('active');
            if (this.dots.length) {
                this.dots.find('.active').removeClass('active');
                $(this.dots.children()[this.getActiveIndex()]).addClass('active');
            }
            parent.trigger(event);
            if (this.flag) {
                this.cycle();
            }
            if (this.options.navigation == 1 && this.dots.find('> div').length > 1) {
                this.setNavigation();
            }
            return this;
        }
    }
    
    $.fn.ba_slider = function (option) {
        return this.each(function () {
            var $this = $(this),
                data = $this.data('ba_slider'),
                options = $.extend({}, $.fn.ba_slider.defaults, typeof option == 'object' && option);
            if (!data) {
                $this.data('ba_slider', (data = new ba_slider(this, options)));
            }
            if (option == 'delete') {
                data.delete('ba_slider');
                $this.removeData();
            } else {
                $this.find('.ba-slider-title').each(function () {
                    if (!$(this).parent().hasClass('slideshow-title-wrapper')) {
                        jQuery(this).wrap('<div class="slideshow-title-wrapper"></div>');
                        if ($(this).html().length == 0) {
                            jQuery(this).parent().addClass('empty-content');
                        }
                    }
                });
                $this.find('.ba-slide-description').each(function () {
                    if (!$(this).parent().hasClass('slideshow-description-wrapper')) {
                        jQuery(this).wrap('<div class="slideshow-description-wrapper"></div>');
                        if ($(this).html().length == 0) {
                            jQuery(this).parent().addClass('empty-content');
                        }
                    }
                });
                $this.addClass(options.effect)
                data.cycle();
                $this.find('[data-ba-slide-to]').on('click.ba_slider', function (event) {
                    event.preventDefault();
                    var index = $(this).attr('data-ba-slide-to');
                    data.to(index);
                });
                $this.find('[data-slide]').on('click.ba_slider',  function (event) {
                    event.preventDefault();
                    var action = $(this).attr('data-slide');
                    data[action]();
                });
            }
        });
    }
    
    $.fn.ba_slider.defaults = {
        interval : 3000,
        autoplay : 1,
        effect : '',
        pause : 0,
        navigation : 0
    }
    
    $.fn.ba_slider.Constructor = ba_slider;

}(window.jQ ? window.jQ : window.jQuery);